==> mcp_server_ogp-0.1.3-py3-none-any.whl: mcp_server_ogp/__init__.py <==
import logging
from mcp_server_ogp.server import mcp


def main():
    """
    OGP Information Server - Model Context Protocol server for extracting Open Graph Protocol information

    This server extracts OGP (Open Graph Protocol) information from specified URLs,
    providing metadata commonly used for social media sharing previews.

    Available features:
    1. ogp_info: Extract OGP information from URLs
    2. ogp_image: Fetch OGP images and return as optimized Image objects
    """
    import argparse

    # Command line argument configuration
    parser = argparse.ArgumentParser(
        description="Start the OGP information extraction server. Extract Open Graph Protocol metadata from web pages."
    )
    parser.add_argument(
        "--sse",
        choices=["on", "off"],
        default="off",
        help='Enable SSE transport when set to "on"',
    )
    parser.add_argument(
        "--host",
        default="localhost",
        help="Host to bind the server to (default: localhost)",
    )
    parser.add_argument(
        "--port",
        type=int,
        default=8000,
        help="Port to bind the server to (default: 8000)",
    )
    parser.add_argument(
        "--log-level",
        choices=["debug", "info", "warning", "error"],
        default="info",
        help="Set logging level:\n"
        "  debug: Detailed debug information\n"
        "  info: General execution information (default)\n"
        "  warning: Potential issues that do not affect execution\n"
        "  error: Errors that occur during execution",
    )
    args = parser.parse_args()

    # Map string log levels to logging constants
    log_level_map = {
        "debug": logging.DEBUG,
        "info": logging.INFO,
        "warning": logging.WARNING,
        "error": logging.ERROR
    }
    
    # Configure logging based on command line argument
    logging.basicConfig(
        level=log_level_map[args.log_level],
        format='%(asctime)s - %(name)s - %(levelname)s - %(message)s'
    )

    # Run server with configured arguments
    if args.sse == "on":
        mcp.run(
            transport="sse", host=args.host, port=args.port, log_level=args.log_level
        )
    else:
        mcp.run(log_level=args.log_level)


if __name__ == "__main__":
    main()


if __name__ == "__main__":
    main()

==> mcp_server_ogp-0.1.4-py3-none-any.whl: mcp_server_ogp/__init__.py <==
import logging
from mcp_server_ogp.server import mcp


def main():
    """
    OGP Information Server - Model Context Protocol server for extracting Open Graph Protocol information

    This server extracts OGP (Open Graph Protocol) information from specified URLs,
    providing metadata commonly used for social media sharing previews.

    Available features:
    1. ogp_info: Extract OGP information from URLs
    2. ogp_image: Fetch OGP images and return as optimized Image objects
    """
    import argparse

    # Command line argument configuration
    parser = argparse.ArgumentParser(
        description="Start the OGP information extraction server. Extract Open Graph Protocol metadata from web pages."
    )
    parser.add_argument(
        "--sse",
        choices=["on", "off"],
        default="off",
        help='Enable SSE transport when set to "on"',
    )
    parser.add_argument(
        "--host",
        default="localhost",
        help="Host to bind the server to (default: localhost)",
    )
    parser.add_argument(
        "--port",
        type=int,
        default=8000,
        help="Port to bind the server to (default: 8000)",
    )
    parser.add_argument(
        "--log-level",
        choices=["debug", "info", "warning", "error"],
        default="info",
        help="Set logging level:\n"
        "  debug: Detailed debug information\n"
        "  info: General execution information (default)\n"
        "  warning: Potential issues that do not affect execution\n"
        "  error: Errors that occur during execution",
    )
    args = parser.parse_args()

    # Map string log levels to logging constants
    log_level_map = {
        "debug": logging.DEBUG,
        "info": logging.INFO,
        "warning": logging.WARNING,
        "error": logging.ERROR
    }

    log_level = log_level_map.get(args.log_level, logging.INFO)
    if args.log_level not in log_level_map:
        raise ValueError(f"Invalid log level: {args.log_level}. Choose from {list(log_level_map.keys())}.")

    # Configure logging based on command line argument
    logging.basicConfig(
        level=log_level,
        format='%(asctime)s - %(name)s - %(levelname)s - %(message)s'
    )

    # Run server with configured arguments
    if args.sse == "on":
        mcp.run(
            transport="sse", host=args.host, port=args.port
        )
    else:
        mcp.run()


if __name__ == "__main__":
    main()


if __name__ == "__main__":
    main()
